package com.ocpsoft.pretty.util.el;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.regex.Pattern;

import com.ocpsoft.pretty.PrettyException;
import com.ocpsoft.pretty.config.mapping.PathParameter;

public abstract class ExpressionProcessor
{
    public static final List<ExpressionProcessor> processors;

    static
    {
        List<ExpressionProcessor> temp = new ArrayList<ExpressionProcessor>();

        temp.add(new NamedExpressionProcessor());
        temp.add(new NamedInjectedParameterProcessor());
        temp.add(new InjectedParameterProcessor());

        processors = Collections.unmodifiableList(temp);
    }

    public abstract PathParameter process(String expression);

    public abstract Pattern getPattern();

    public static PathParameter process(final List<ExpressionProcessor> processors, final String expression)
    {
        PathParameter result = null;
        for (ExpressionProcessor p : processors)
        {
            result = p.process(expression);

            if (result != null)
            {
                break;
            }
        }

        if (result == null)
        {
            throw new PrettyException("Malformed EL expression: " + expression + ", discovered.");
        }

        return result;
    }

    public static String removeEl(final List<ExpressionProcessor> processors, final String expression)
    {
        String result = expression;
        for (ExpressionProcessor p : processors)
        {
            result = p.getPattern().matcher(result).replaceAll("([^/]+)");
        }
        return result;
    }
}
